@@ -43,6 +43,7 @@
 /* #undef HAVE_IA64INTRIN_H */
 /* #undef HAVE_IEEEFP_H */
 #define HAVE_INTTYPES_H 1
+#define HAVE_IMMINTRIN_H 1
 /* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
 #define HAVE_LINK_H 1
@@ -501,14 +502,6 @@
 #define HAVE_des 1
 #define HAVE_hkdf 1
 
-/*
-  Stuff that always need to be defined (compile breaks without it)
-*/
-#define HAVE_SPATIAL 1
-#define HAVE_RTREE_KEYS 1
-#define HAVE_QUERY_CACHE 1
-#define BIG_TABLES 1
-
 /*
   Important storage engines (those that really need define 
   WITH_<ENGINE>_STORAGE_ENGINE for the whole server)
@@ -531,17 +524,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 11
-#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_MINOR 7
 #define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 11.6.2"
+#define PACKAGE_STRING "MySQL Server 11.7.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "11.6.2"
-#define VERSION "11.6.2"
+#define PACKAGE_VERSION "11.7.2"
+#define VERSION "11.7.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
